@@ -1,4 +1,4 @@
-""" RESQML manipulation library
+"""RESQML manipulation library.
 
 .. autosummary::
     :toctree: _autosummary
@@ -23,12 +23,11 @@
     weights_and_measures
     well
     olio
-
 """
 
 try:
-   # Version dynamically extracted from git tags when package is built
-   from .version import version as __version__  # type: ignore
+    # Version dynamically extracted from git tags when package is built
+    from .version import version as __version__  # type: ignore
 
 except ImportError:
-   __version__ = "0.0.0-version-not-available"
+    __version__ = "0.0.0-version-not-available"
